@@ -241,6 +241,10 @@ class Graph(IWidget):
         for entry in values:
             color = entry["color"]
             data = entry["data"]
+            if self.quiet is True:
+                quiet = True
+            else:
+                quiet = entry.get("quiet", False)
 
             def scale_y_value(value):
                 """ Scale the value to fit the graph box."""
@@ -263,7 +267,7 @@ class Graph(IWidget):
                     prev_y = y
 
                 # Render the graph trailing value
-                if self.quiet is not True:
+                if quiet is not True:
                     text = self.graph_font.render(
                         snapped_value_string(data[-1], 0.1),
                         1,
